@@ -26,9 +26,9 @@ my $day    = strftime "%d", localtime();
 my $year   = strftime "%Y", localtime();
 my $out    = $mydir . "/md5file-" . $year . $month1 . $day;
 
-open my $Ofile, ">", $out or die $!;
+open my $Ofile, ">>", $out or die $!;
 
-my $result = md5init($mydir);
+my $result = md5init($mydir,$Ofile);
 
 print $Ofile $result;
 
